@@ -2,11 +2,16 @@ from typing import Dict, Optional
 
 from jinja2 import Environment, FileSystemLoader
 
+from aws_managers.athena.athena_ser_des import AthenaSerDes
 from aws_managers.paths.dirs import DIR_ATHENA_TEMPLATES
 
 
 class AthenaQueryGenerator(object):
 
+    SER_DES = {
+        'parquet': 'org.apache.hadoop.hive.ql.io.parquet.serde.ParquetHiveSerDe',
+
+    }
     PARQUET_HIVE_SERDE = (
         'org.apache.hadoop.hive.ql.io.parquet.serde.ParquetHiveSerDe'
     )
@@ -15,18 +20,30 @@ class AthenaQueryGenerator(object):
 
         self.env = Environment(loader=FileSystemLoader(DIR_ATHENA_TEMPLATES))
 
-    @staticmethod
     def create_table(
+        self,
         db_name: str,
         table_name: str,
-        columns: Dict[str, str] = None,
+        columns: Dict[str, str],
+        location: str,
+        serialization_format: int = 1,
+        row_format: str = AthenaSerDes.Parquet,
         partition_column: Optional[str] = None,
         encrypted: bool = False
     ) -> str:
         """
         Run this query to create a table pointing to parquet data in S3.
         """
-        raise NotImplementedError
+        t = self.env.get_template('create_table.jinja2')
+        return t.render(
+            db_name=db_name,
+            table_name=table_name,
+            columns=columns,
+            location=location,
+            serialization_format=serialization_format,
+            row_format=row_format,
+            encrypted=str(encrypted).lower()
+        )
 
     def repair_table(
             self,
